@@ -1,20 +1,26 @@
 /* hmap.h - A hash table (map datatype) implementation.
  *
- * Copyright (C) 2001  Oskar Liljeblad
+ * Copyright (C) 1998-2005 Oskar Liljeblad
  *
- * This file is part of the file renaming utilities (renameutils)
- * and regex-markup.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This software is copyrighted work licensed under the terms of the
- * GNU General Public License. Please consult the file `COPYING' for
- * details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-#ifndef __HMAP_H__
-#define __HMAP_H__
+#ifndef COMMON_HMAP_H
+#define COMMON_HMAP_H
 
-#include <sys/types.h>
-#include "common.h"
+#include <stdint.h>		/* POSIX/Gnulib */
 #include "collections.h"
 #include "iterator.h"
 
