@@ -1,20 +1,27 @@
 /* time64.h - Complete time: microseconds and seconds condensed into an int64_t
  *
- * Copyright (C) 2001  Oskar Liljeblad
+ * Copyright (C) 1998-2005 Oskar Liljeblad
  *
- * This file is part of the file renaming utilities (renameutils)
- * and regex-markup.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This software is copyrighted work licensed under the terms of the
- * GNU General Public License. Please consult the file `COPYING' for
- * details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
 #ifndef COMMON_TIME64_H
 #define COMMON_TIME64_H
 
-#include <stdint.h>
-#include <sys/time.h>
+#include <stdint.h>	/* POSIX/Gnulib */
+#include <sys/time.h>	/* POSIX */
 
 #define MICROS_PER_SEC	1000000LL
 
