@@ -1,14 +1,38 @@
+/* win32-endian.c - Correcting endian-ness of data loaded to memory
+ *
+ * Copyright (C) 1998-2005 Oskar Liljeblad
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ */
+
 #include <config.h>
 #include "win32-endian.h"
 
-#ifdef HAVE_BYTESWAP_H
-#include <byteswap.h>
-#endif 
+#if HAVE_BYTESWAP_H
+#include <byteswap.h>			/* FIXME */
+#elif defined(__APPLE__)	
+#include <machine/byte_order.h>
+#define bswap_16(x) NXSwapShort(x)
+#define bswap_32(x) NXSwapInt(x)
+#define bswap_64(x) NXSwapLongLong(x)
+#endif
 
 #define BSWAP16(x)  	((x) = bswap_16(x))
 #define BSWAP32(x)  	((x) = bswap_32(x))
 
-#ifdef WORDS_BIGENDIAN
+#if WORDS_BIGENDIAN
 
 void
 fix_win32_cursor_icon_file_dir_endian(Win32CursorIconFileDir *obj)
