@@ -1,5 +1,6 @@
-/* icoutils - A set of programs dealing with MS Windows icons and cursors.
- * Copyright (C) 1998-1999 Oskar Liljeblad
+/* extract.c - Extract icon and cursor files from PE and NE files
+ * 
+ * Copyright (C) 1998-2005 Oskar Liljeblad
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,6 +18,9 @@
  */
 
 #include <config.h>
+#include "gettext.h"			/* Gnulib */
+#define _(s) gettext(s)
+#define N_(s) gettext_noop(s)
 #include "common/memory.h"
 #include "common/error.h"
 #include "common/intparse.h"
@@ -24,7 +28,6 @@
 #include "fileread.h"
 #include "wrestool.h"
 
-
 static void *extract_group_icon_cursor_resource(WinLibrary *, WinResource *, char *, int *, bool);
 
 void
@@ -97,7 +100,7 @@ extract_resource (WinLibrary *fi, WinResource *wr, int *size,
 		}
 	}
 
-	warn("%s: don't know how to extract resource, try `--raw'", fi->name);
+	warn(_("%s: don't know how to extract resource, try `--raw'"), fi->name);
 	return NULL;
 }
 
@@ -150,19 +153,19 @@ extract_group_icon_cursor_resource(WinLibrary *fi, WinResource *wr, char *lang,
 		snprintf(name, sizeof(name)/sizeof(char), "-%d", icondir->entries[c].res_id);
 		fwr = find_resource(fi, (is_icon ? "-3" : "-1"), name, lang, &level);
 		if (fwr == NULL) {
-			warn("%s: could not find `%s' in `%s' resource.",
+			warn(_("%s: could not find `%s' in `%s' resource."),
 			 	fi->name, &name[1], (is_icon ? "group_icon" : "group_cursor"));
 			return NULL;
 		}
 
 		if (get_resource_entry(fi, fwr, &iconsize) != NULL) {
 		    if (iconsize == 0) {
-			warn("%s: icon resource `%s' is empty, skipping", fi->name, name);
+			warn(_("%s: icon resource `%s' is empty, skipping"), fi->name, name);
 			skipped++;
 			continue;
 		    }
 		    if (iconsize != icondir->entries[c].bytes_in_res) {
-			warn("%s: mismatch of size in icon resource `%s' and group", fi->name, name);
+			warn(_("%s: mismatch of size in icon resource `%s' and group (%d vs %d)"), fi->name, name, iconsize, icondir->entries[c].bytes_in_res);
 		    }
 		    size += iconsize; /* size += icondir->entries[c].bytes_in_res; */
 
@@ -197,7 +200,7 @@ extract_group_icon_cursor_resource(WinLibrary *fi, WinResource *wr, char *lang,
 		snprintf(name, sizeof(name)/sizeof(char), "-%d", icondir->entries[c].res_id);
 		fwr = find_resource(fi, (is_icon ? "-3" : "-1"), name, lang, &level);
 		if (fwr == NULL) {
-			warn("%s: could not find `%s' in `%s' resource.",
+			warn(_("%s: could not find `%s' in `%s' resource."),
 			 	fi->name, &name[1], (is_icon ? "group_icon" : "group_cursor"));
 			return NULL;
 		}
