@@ -1,5 +1,6 @@
-/* icoutils - A set of programs dealing with MS Windows icons and cursors.
- * Copyright (C) 1998-1999 Oskar Liljeblad
+/* wrestool.h - Common definitions for wrestool
+ *
+ * Copyright (C) 1998-2005 Oskar Liljeblad
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,15 +17,17 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-#include <features.h>
-#include <unistd.h>
-#include <stdarg.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <errno.h>
-#include <getopt.h>
+#ifndef WRESTOOL_H
+#define WRESTOOL_H
+
+#include <unistd.h>		/* POSIX */
+#include <stdarg.h>		/* C89 */
+#include <stdio.h>		/* C89 */
+#include <stdlib.h>		/* C89 */
+#include <stdint.h>		/* POSIX/Gnulib */
+#include <string.h>		/* C89 */
+#include <errno.h>		/* C89 */
+#include <getopt.h>		/* GNU Libc/Gnulib */
 #include "common/common.h"
 //#include "../common/win32.h"
 //#include "../common/fileread.h"
@@ -87,13 +90,13 @@ typedef void (*DoResourceCallback) (WinLibrary *, WinResource *, WinResource *,
  */
 
 /* resource.c */
-WinResource *list_resources (WinLibrary *, WinResource *, int *);
+/* WinResource *list_resources (WinLibrary *, WinResource *, int *); */
 bool read_library (WinLibrary *);
 WinResource *find_resource (WinLibrary *, char *, char *, char *, int *);
 void *get_resource_entry (WinLibrary *, WinResource *, int *);
 void do_resources (WinLibrary *, char *, char *, char *, DoResourceCallback);
 void print_resources_callback (WinLibrary *, WinResource *, WinResource *, WinResource *, WinResource *);
-bool compare_resource_id (WinResource *, char *);
+/* bool compare_resource_id (WinResource *, char *); */
 
 /* main.c */
 char *res_type_id_to_string (int);
@@ -102,3 +105,5 @@ char *get_destination_name (WinLibrary *, char *, char *, char *);
 /* extract.c */
 void *extract_resource (WinLibrary *, WinResource *, int *, bool *, char *, char *, bool);
 void extract_resources_callback (WinLibrary *, WinResource *, WinResource *, WinResource *, WinResource *);
+
+#endif
